==> dhp-schemas-2.7.18-20210907.235057-15-sources.jar: eu/dnetlib/dhp/schema/dump/oaf/Instance.java <==

package eu.dnetlib.dhp.schema.dump.oaf;

import java.io.Serializable;
import java.util.List;

/**
 * Represents the manifestations (i.e. different versions) of the result. For example: the pre-print and the published
 * versions are two manifestations of the same research result. It has the following parameters: - license of type
 * String to store the license applied to the instance. It corresponds to the value of the licence in the instance to be
 * dumped - accessright of type eu.dnetlib.dhp.schema.dump.oaf.AccessRight to store the accessright of the instance. -
 * type of type String to store the type of the instance as defined in the corresponding dnet vocabulary
 * (dnet:pubication_resource). It corresponds to the instancetype.classname of the instance to be mapped - url of type
 * List<String> list of locations where the instance is accessible. It corresponds to url of the instance to be dumped -
 * publicationdate of type String to store the publication date of the instance ;// dateofacceptance; - refereed of type
 * String to store information abour the review status of the instance. Possible values are 'Unknown',
 * 'nonPeerReviewed', 'peerReviewed'. It corresponds to refereed.classname of the instance to be dumped
 * - articleprocessingcharge of type APC to store the article processing charges possibly associated to the instance
 * -pid of type List<ControlledField> that is the list of pids associated to the result coming from authoritative sources for that pid
 * -alternateIdentifier of type List<ControlledField> that is the list of pids associated to the result coming from NON authoritative
 * sources for that pid
 */
public class Instance implements Serializable {

	private List<ControlledField> pid;

	private List<ControlledField> alternateIdentifier;

	private String license;

	private AccessRight accessright;

	private String type;

	private List<String> url;

	private APC articleprocessingcharge;

	private String publicationdate;// dateofacceptance;

	private String refereed; // peer-review status

	public String getLicense() {
		return license;
	}

	public void setLicense(String license) {
		this.license = license;
	}

	public AccessRight getAccessright() {
		return accessright;
	}

	public void setAccessright(AccessRight accessright) {
		this.accessright = accessright;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public List<String> getUrl() {
		return url;
	}

	public void setUrl(List<String> url) {
		this.url = url;
	}

	public String getPublicationdate() {
		return publicationdate;
	}

	public void setPublicationdate(String publicationdate) {
		this.publicationdate = publicationdate;
	}

	public String getRefereed() {
		return refereed;
	}

	public void setRefereed(String refereed) {
		this.refereed = refereed;
	}

	public APC getArticleprocessingcharge() {
		return articleprocessingcharge;
	}

	public void setArticleprocessingcharge(APC articleprocessingcharge) {
		this.articleprocessingcharge = articleprocessingcharge;
	}

	public List<ControlledField> getPid() {
		return pid;
	}

	public void setPid(List<ControlledField> pid) {
		this.pid = pid;
	}

	public List<ControlledField> getAlternateIdentifier() {
		return alternateIdentifier;
	}

	public void setAlternateIdentifier(List<ControlledField> alternateIdentifier) {
		this.alternateIdentifier = alternateIdentifier;
	}
}

==> dhp-schemas-2.9.24-20211214.005152-26-sources.jar: eu/dnetlib/dhp/schema/dump/oaf/Instance.java <==

package eu.dnetlib.dhp.schema.dump.oaf;

import java.io.Serializable;
import java.util.List;

/**
 * Represents the manifestations (i.e. different versions) of the result. For example: the pre-print and the published
 * versions are two manifestations of the same research result. It has the following parameters: - license of type
 * String to store the license applied to the instance. It corresponds to the value of the licence in the instance to be
 * dumped - accessright of type eu.dnetlib.dhp.schema.dump.oaf.AccessRight to store the accessright of the instance. -
 * type of type String to store the type of the instance as defined in the corresponding dnet vocabulary
 * (dnet:pubication_resource). It corresponds to the instancetype.classname of the instance to be mapped - url of type
 * List<String> list of locations where the instance is accessible. It corresponds to url of the instance to be dumped -
 * publicationdate of type String to store the publication date of the instance ;// dateofacceptance; - refereed of type
 * String to store information abour the review status of the instance. Possible values are 'Unknown',
 * 'nonPeerReviewed', 'peerReviewed'. It corresponds to refereed.classname of the instance to be dumped
 * - articleprocessingcharge of type APC to store the article processing charges possibly associated to the instance
 * -pid of type List<ControlledField> that is the list of pids associated to the result coming from authoritative sources for that pid
 * -alternateIdentifier of type List<ControlledField> that is the list of pids associated to the result coming from NON authoritative
 * sources for that pid
 * -measure list<KeyValue> to represent the measure computed for this instance (for example the Bip!Finder ones). It corresponds to measures in the model
 */
public class Instance implements Serializable {

	private List<KeyValue> measures;

	private List<ControlledField> pid;

	private List<ControlledField> alternateIdentifier;

	private String license;

	private AccessRight accessright;

	private String type;

	private List<String> url;

	private APC articleprocessingcharge;

	private String publicationdate;// dateofacceptance;

	private String refereed; // peer-review status

	public String getLicense() {
		return license;
	}

	public void setLicense(String license) {
		this.license = license;
	}

	public AccessRight getAccessright() {
		return accessright;
	}

	public void setAccessright(AccessRight accessright) {
		this.accessright = accessright;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public List<String> getUrl() {
		return url;
	}

	public void setUrl(List<String> url) {
		this.url = url;
	}

	public String getPublicationdate() {
		return publicationdate;
	}

	public void setPublicationdate(String publicationdate) {
		this.publicationdate = publicationdate;
	}

	public String getRefereed() {
		return refereed;
	}

	public void setRefereed(String refereed) {
		this.refereed = refereed;
	}

	public APC getArticleprocessingcharge() {
		return articleprocessingcharge;
	}

	public void setArticleprocessingcharge(APC articleprocessingcharge) {
		this.articleprocessingcharge = articleprocessingcharge;
	}

	public List<ControlledField> getPid() {
		return pid;
	}

	public void setPid(List<ControlledField> pid) {
		this.pid = pid;
	}

	public List<ControlledField> getAlternateIdentifier() {
		return alternateIdentifier;
	}

	public void setAlternateIdentifier(List<ControlledField> alternateIdentifier) {
		this.alternateIdentifier = alternateIdentifier;
	}

	public List<KeyValue> getMeasures() {
		return measures;
	}

	public void setMeasures(List<KeyValue> measures) {
		this.measures = measures;
	}
}
